==> robotmk-0.0.111-py2.py3-none-any.whl: robotmk/context/suite/target/target_factory.py <==
from pathlib import Path
from robotmk.logger import RobotmkLogger
from .abstract import Target

from .local.robotframework import RobotFrameworkTarget
from .local.rcc import RCCTarget
from .remote import RemoteTarget


class TargetFactory:
    def __init__(self, suiteuname: str, config, logger: RobotmkLogger):
        self.suiteuname = suiteuname
        self.config = config
        self.logger = logger

    def create(self) -> Target:
        """Create a target object."""
        otarget = None
        suitecfg = self.config.get("suites.%s" % self.suiteuname)
        if suitecfg == None:
            self.error("Suite '%s' is not part of the config!" % self.suiteuname)

        target_name = suitecfg.get("run.target")
        if target_name == "local":
            path = Path(self.config.get("common.robotdir")).joinpath(
                suitecfg.get("path")
            )
            if path.exists():
                if suitecfg.get("run.rcc", False):
                    print("I will choose RCC")
                    otarget = RCCTarget(self.suiteuname, self.config, self.logger)
                else:
                    print("I will choose RF")
                    otarget = RobotFrameworkTarget(
                        self.suiteuname, self.config, self.logger
                    )
            else:
                # TBD: check this if this gets logged...
                self.error("Suite path does not exist: " + str(path))
        elif target_name == "remote":
            otarget = RemoteTarget(self.suiteuname, self.config, self.logger)
        else:
            self.error("Unknown target type for suite %s!" % self.suiteuname)
        return otarget

==> robotmk-0.0.112-py2.py3-none-any.whl: robotmk/context/suite/target/target_factory.py <==
from pathlib import Path
from robotmk.logger import RobotmkLogger
from .abstract import Target

from .local.robotframework import RobotFrameworkTarget
from .local.rcc import RCCTarget
from .remote import RemoteTarget


class TargetFactory:
    def __init__(self, suiteuname: str, config, logger: RobotmkLogger):
        self.suiteuname = suiteuname
        self.config = config
        self.logger = logger

    def create(self) -> Target:
        """Create a target object."""
        otarget = None
        suitecfg = self.config.get("suites.%s" % self.suiteuname)
        if suitecfg == None:
            self.error("Suite '%s' is not part of the config!" % self.suiteuname)

        target_name = suitecfg.get("run.target")
        if target_name == "local":
            path = Path(self.config.get("common.robotdir")).joinpath(
                suitecfg.get("path")
            )
            if path.exists():
                if suitecfg.get("run.rcc", False):
                    # print("I will choose RCC")
                    otarget = RCCTarget(self.suiteuname, self.config, self.logger)
                else:
                    # print("I will choose RF")
                    otarget = RobotFrameworkTarget(
                        self.suiteuname, self.config, self.logger
                    )
            else:
                # TBD: check this if this gets logged...
                self.error("Suite path does not exist: " + str(path))
        elif target_name == "remote":
            otarget = RemoteTarget(self.suiteuname, self.config, self.logger)
        else:
            self.error("Unknown target type for suite %s!" % self.suiteuname)
        return otarget
